/* Programme GPS, pour developpement d'une centrale de navigation dériveur.
 *  
 *  Rémi PERRIN , Septembre 2016
 *  
 *  Lien de discussion sur le forum www.d-one-france.fr
 *  http://www.d-one-france.fr/index.php/forum/bricolage/214-speedo-tracker-pour-quelques-dizaines-d-euro#2350
 *  
 *  Affichage Date/Time , Cap , Vitesse
 *  
 *  Logging sur carte SD
 */

#include <SPI.h>
#include <SD.h> 
#include <TinyGPS++.h>
#include <SoftwareSerial.h>


/*
   Lecteur de carte SD sur pin 4
   GPS recepteur connecté sur l'entree serial pins 2(RX) and 3(TX) à 9600 baud
*/

// Parametres de connection du Shield SD
const int chipSelect = 4;

// Paramètres de connection du recepteur GPS
static const int RXPin = 2, TXPin = 3;
static const uint32_t GPSBaud = 9600;

// The TinyGPS++ object
TinyGPSPlus gps;

// The serial connection to the GPS device
SoftwareSerial ss(RXPin, TXPin);


void setup() 
{
  
  Serial.begin(9600);
  ss.begin(GPSBaud);

 
  Serial.print("Initialisation carte SD ...");

  
  if (!SD.begin(4)) 
  {
    Serial.println("erreur d'initialisation !");
    return;
  }
  
  Serial.println("initialisation effectuée ...");

  // Ouverture du fichier d'enregistrement
  File dataLogFile = SD.open("Idefix.txt", FILE_WRITE);

  // if the file opened okay, write to it:
  if (dataLogFile) 
  {
    dataLogFile.println(F("www.d-one-france-fr"));
    dataLogFile.println(F("GPS_Idefix_v00.4 , par Remi Perrin"));
    dataLogFile.println(F("Developpement d'une centrale de navigation pour deriveur, sur base Arduino"));
    dataLogFile.println();
    dataLogFile.print(F("Utilisation TinyGPS++ library v. ")); dataLogFile.println(TinyGPSPlus::libraryVersion());
    dataLogFile.println();

  
    // close the file:
    dataLogFile.close();
    Serial.println("entete de fichier enregistree ... ");
  } 
  else 
  {
    // Si erreur d'ouverture du fichier SD carte:
    Serial.println("erreur d'ouverture du fichier d'enregistrement");
  }


  
  Serial.println("debut de l'enregistrement dans 5 secondes");
  delay(5000);

  
}

void loop() 
{
  File dataLogFile = SD.open("Idefix.txt", FILE_WRITE);

  // if the file is available, write to it:
  if (dataLogFile) 
  {
    // Quand donnee disponibles, donnee enregistrees
    if (gps.speed.isUpdated() || gps.date.isUpdated() || gps.time.isUpdated() || gps.course.isUpdated() )
    {
      dataLogFile.print(F("Date="));   dataLogFile.print(gps.date.value()); 
      dataLogFile.print(F("  Heure="));   dataLogFile.print(gps.time.value()); 
      dataLogFile.print(F("  Cap="));   dataLogFile.print(gps.course.deg(),1); 
      dataLogFile.print(F("  Speed="));   dataLogFile.print(gps.speed.knots());
      dataLogFile.print(F("  Latitude="));   dataLogFile.print(gps.location.lat(),6);
      dataLogFile.print(F("  Longitude="));   dataLogFile.println(gps.location.lng(),6);       
    }

    while (ss.available() > 0)
    gps.encode(ss.read());
  }
  // si probleme sur le fichier d'enregistrement, envoi d'une erreur
  else
  {
    Serial.println("error opening Idefix.txt");
  }
 dataLogFile.close(); 
}  
